@@ -311,7 +311,8 @@ func run() error {
 		calls = append(calls, taskfile.Call{Task: "default", Direct: true})
 	}
 
-	globals.Set("CLI_ARGS", taskfile.Var{Static: cliArgs})
+	globals.Set("CLI_ARGS", taskfile.Var{Value: cliArgs})
+	globals.Set("CLI_FORCE", taskfile.Var{Value: flags.force || flags.forceAll})
 	e.Taskfile.Vars.Merge(globals)
 
 	if !flags.watch {
