@@ -7,6 +7,7 @@ import (
 
 	"github.com/joho/godotenv"
 
+	"github.com/go-task/task/v3/errors"
 	"github.com/go-task/task/v3/internal/execext"
 	"github.com/go-task/task/v3/internal/filepathext"
 	"github.com/go-task/task/v3/internal/fingerprint"
@@ -96,7 +97,7 @@ func (e *Executor) compiledTask(call taskfile.Call, evaluateShVars bool) (*taskf
 			}
 			for key, value := range envs {
 				if ok := dotenvEnvs.Exists(key); !ok {
-					dotenvEnvs.Set(key, taskfile.Var{Static: value})
+					dotenvEnvs.Set(key, taskfile.Var{Value: value})
 				}
 			}
 		}
@@ -108,11 +109,16 @@ func (e *Executor) compiledTask(call taskfile.Call, evaluateShVars bool) (*taskf
 	new.Env.Merge(r.ReplaceVars(origTask.Env))
 	if evaluateShVars {
 		err = new.Env.Range(func(k string, v taskfile.Var) error {
+			// If the variable is not dynamic, we can set it and return
+			if v.Value != nil || v.Sh == "" {
+				new.Env.Set(k, taskfile.Var{Value: v.Value})
+				return nil
+			}
 			static, err := e.Compiler.HandleDynamicVar(v, new.Dir)
 			if err != nil {
 				return err
 			}
-			new.Env.Set(k, taskfile.Var{Static: static})
+			new.Env.Set(k, taskfile.Var{Value: static})
 			return nil
 		})
 		if err != nil {
@@ -127,32 +133,54 @@ func (e *Executor) compiledTask(call taskfile.Call, evaluateShVars bool) (*taskf
 				continue
 			}
 			if cmd.For != nil {
-				var list []string
+				var keys []string
+				var list []any
 				// Get the list from the explicit for list
 				if cmd.For.List != nil && len(cmd.For.List) > 0 {
 					list = cmd.For.List
 				}
 				// Get the list from the task sources
 				if cmd.For.From == "sources" {
-					list, err = fingerprint.Globs(new.Dir, new.Sources)
+					glist, err := fingerprint.Globs(new.Dir, new.Sources)
 					if err != nil {
 						return nil, err
 					}
 					// Make the paths relative to the task dir
-					for i, v := range list {
-						if list[i], err = filepath.Rel(new.Dir, v); err != nil {
+					for i, v := range glist {
+						if glist[i], err = filepath.Rel(new.Dir, v); err != nil {
 							return nil, err
 						}
 					}
+					list = asAnySlice(glist)
 				}
 				// Get the list from a variable and split it up
 				if cmd.For.Var != "" {
 					if vars != nil {
 						v := vars.Get(cmd.For.Var)
-						if cmd.For.Split != "" {
-							list = strings.Split(v.Static, cmd.For.Split)
-						} else {
-							list = strings.Fields(v.Static)
+						// If the variable is dynamic, then it hasn't been resolved yet
+						// and we can't use it as a list. This happens when fast compiling a task
+						// for use in --list or --list-all etc.
+						if v.Value != nil && v.Sh == "" {
+							switch value := v.Value.(type) {
+							case string:
+								if cmd.For.Split != "" {
+									list = asAnySlice(strings.Split(value, cmd.For.Split))
+								} else {
+									list = asAnySlice(strings.Fields(value))
+								}
+							case []any:
+								list = value
+							case map[string]any:
+								for k, v := range value {
+									keys = append(keys, k)
+									list = append(list, v)
+								}
+							default:
+								return nil, errors.TaskfileInvalidError{
+									URI: origTask.Location.Taskfile,
+									Err: errors.New("var must be a delimiter-separated string or a list"),
+								}
+							}
 						}
 					}
 				}
@@ -164,10 +192,13 @@ func (e *Executor) compiledTask(call taskfile.Call, evaluateShVars bool) (*taskf
 					as = "ITEM"
 				}
 				// Create a new command for each item in the list
-				for _, loopValue := range list {
+				for i, loopValue := range list {
 					extra := map[string]any{
 						as: loopValue,
 					}
+					if len(keys) > 0 {
+						extra["KEY"] = keys[i]
+					}
 					new.Cmds = append(new.Cmds, &taskfile.Cmd{
 						Cmd:         r.ReplaceWithExtra(cmd.Cmd, extra),
 						Task:        r.ReplaceWithExtra(cmd.Task, extra),
@@ -243,3 +274,11 @@ func (e *Executor) compiledTask(call taskfile.Call, evaluateShVars bool) (*taskf
 
 	return &new, r.Err()
 }
+
+func asAnySlice[T any](slice []T) []any {
+	ret := make([]any, len(slice))
+	for i, v := range slice {
+		ret[i] = v
+	}
+	return ret
+}
